<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>OutputNullFactory</name>
    <message>
        <location filename="../outputnullfactory.cpp" line="30"/>
        <source>Null Plugin</source>
        <translation>无输出插件</translation>
    </message>
    <message>
        <location filename="../outputnullfactory.cpp" line="54"/>
        <source>About Null Output Plugin</source>
        <translation>关于无输出插件</translation>
    </message>
    <message>
        <location filename="../outputnullfactory.cpp" line="55"/>
        <source>Qmmp Null Output Plugin</source>
        <translation>Qmmp 无输出插件</translation>
    </message>
    <message>
        <location filename="../outputnullfactory.cpp" line="56"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
